@@ -2,6 +2,7 @@
 
 use crate::ContentDeserializer;
 use glib::translate::*;
+use glib::value::FromValue;
 
 impl ContentDeserializer {
     pub fn set_value(&self, value: glib::Value) {
@@ -24,12 +25,22 @@ impl ContentDeserializer {
         }
     }
 
+    // rustdoc-stripper-ignore-next
+    /// Similar to [`Self::value`] but panics if the value is of a different type.
+    #[doc(alias = "gdk_content_deserializer_get_value")]
+    #[doc(alias = "get_value")]
+    pub fn value_as<V: for<'b> FromValue<'b> + 'static>(&self) -> V {
+        self.value()
+            .get_owned::<V>()
+            .expect("Failed to get the value")
+    }
+
     #[doc(alias = "gdk_content_deserializer_return_error")]
     pub fn return_error(&self, error: glib::Error) {
         unsafe {
             ffi::gdk_content_deserializer_return_error(
                 self.to_glib_none().0,
-                mut_override(error.to_glib_full()),
+                mut_override(error.into_glib_ptr()),
             );
         }
     }
